/*
 * Copyright (c) 2009 Scott E. Johnston
 * Copyright (c) 1996,1999 Vectaport Inc.
 * Copyright (c) 1990, 1991 Stanford University
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

/*
 * DrawImportCmd - a command for importing graphs in multi-frame situations
 */

#ifndef draw_import_h
#define draw_import_h

#include <FrameUnidraw/frameimport.h>

#include <stdio.h>

//: specialized FrameImportCmd for importing graphs in frames
class DrawImportCmd : public FrameImportCmd {
public:
    DrawImportCmd(ControlInfo*, ImportChooser* = nil);
    DrawImportCmd(Editor* = nil, ImportChooser* = nil);

    virtual void Execute();
    virtual Command* Copy();
    virtual ClassId GetClassId();
    virtual boolean IsA(ClassId);

    virtual GraphicComp* Import(const char*);
};

//: specialized ImportPasteCmd for DrawServ
class DrawImportPasteCmd : public FrameImportPasteCmd {
public:
    DrawImportPasteCmd(ControlInfo*, Clipboard* = nil);
    DrawImportPasteCmd(Editor* = nil, Clipboard* = nil);
    virtual ~DrawImportPasteCmd();

    virtual void Execute();

    virtual Command* Copy();
    virtual ClassId GetClassId();
    virtual boolean IsA(ClassId);

 protected:
};

#endif
