/*
 * Copyright (c) 1994 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

#include <cstdio>
#include <Time/obstime.h>

ObservableTime::ObservableTime(Time* th) {
    th_ = new Time();
    if (th)
	*th_ = *th;
}

ObservableTime::~ObservableTime() {}

Time* ObservableTime::time() {
    return th_;
}

void ObservableTime::time(Time* th) {
    *th_ = *th;
    notify();
}

void ObservableTime::time(Time& th) {
    *th_ = th;
    notify();
}

void ObservableTime::addsecond(long sec) {
    *th_ += sec;
    notify();
}

void ObservableTime::addminute(long min) {
    *th_ += min * 60;
    notify();
}

void ObservableTime::addhour(long hr) {
    *th_ += hr * 3600;
    notify();
}

void ObservableTime::addday(long day) {
    *th_ +=  day * 3600 * 24;
    notify();
}

